clear all
close all
syms m x y dx dy fx fy ft fn l real

%Let's constrain a pointmass on a circle
c = x^2 + y^2 - l^2;

%Let's apply forces tangential and normal to the circle
fx =  (-y * ft + x * fn)/sqrt(x^2 + y^2);
fy =  ( x * ft + y * fn)/sqrt(x^2 + y^2);

%Let's compute the system dynamics constrained on the circle
A = [diff(c,x) diff(c,y) ];
dA = [diff(diff(c,x),x)*dx+diff(diff(c,x),y)*dy diff(diff(c,y),x)*dx+diff(diff(c,y),y)*dy];

F = [fx; fy];
M = [m 0; 0 m];
lambda = (A*inv(M)*A')^(-1) * (A*inv(M)*F + dA*[dx; dy]);
d2q = inv(M) * ([fx; fy] - A' * lambda);

d2x = simple(d2q(1));
d2y = simple(d2q(2));

%Let's check that distance of the mass from the center of the circle is 
%constant
r = x*x + y*y;
dr  = diff(r, x)  * dx  + diff(r, y)  * dy;
d2r = diff(r, x)  * d2x + diff(r, y)  * d2y + 2*diff(diff(r, y),x) * dx * dy + diff(diff(r, x),x) * dx * dx + diff(diff(r, y),y) * dy * dy;
d2r = simple(d2r);
d2r

%Let's check that the angle is evolving as a pendolum
theta   = atan(y/x);
dtheta  = diff(theta, x)  * dx + diff(theta, y)  * dy;
dtheta = simple(dtheta);
d2theta = diff(theta, x) * d2x + diff(theta, y) * d2y + 2*diff(diff(theta, y),x) * dx * dy + diff(diff(theta, x),x) * dx * dx + diff(diff(theta, y),y) * dy * dy;
d2theta = simple(d2theta);

%Let's impose that c=0, dc=0
dc = diff(c,x)*dx + diff(c,y)*dy;
S = solve(strcat(char(dc), '=0'), 'dx');
d2theta = simple(subs(d2theta, dx, S));
d2theta


